@@ -10,7 +10,7 @@ use HTML::Parser;
 use HTML::Form;
 use Digest::MD5();
 
-our $VERSION = '9.01';
+our $VERSION = '9.02';
 
 # $Id: $
 # $Log: LaPoste.pm,v $
@@ -246,7 +246,6 @@ sub _GET_content {
 sub _list_accounts {
     my ($self, $response) = @_;
     my $html = $response->content;
-    #_output("/tmp/t.html", $html);
     my @l = _list_accounts_one_page($self, $html);
 
     if ($self->{all_accounts}) {
@@ -276,19 +275,16 @@ sub _list_accounts_one_page {
             push @l, { url => $url, balance => $balance, name => $name, owner => $owner, account_no => $account_no, type => $type } if $url;
             $url = '';
         } elsif ($flag eq 'balance_cb' && m!<span>([\d\s,.+-]*)!) {
+	    $flag = '';
             $balance_cb = $normalize_number->($1);            
-        } elsif (m!<a href="(.*?mouvementsCarteDD.*?)"!) {
-            my $cb_url = $1;
-            $cb_url =~ s/&amp;/&/g;
-            push @l, { url => $cb_url, balance => $balance_cb, name => "Carte bancaire", owner => $owner, account_no => $account_no, type => 'cb' }  if $self->{cb_accounts} || $self->{all_accounts};
+            $url =~ s/&amp;/&/g;
+            push @l, { url => $url, balance => $balance_cb, name => "Carte bancaire", owner => $owner, account_no => $account_no, type => 'cb' }  if $self->{cb_accounts} || $self->{all_accounts};
         }
 
         if (/account-resume--banq|account-resume--saving/) {
             $flag = 'url';
         } elsif (/D&#233;bit diff&#233;r&#233; en cours/) {
             $flag = 'balance_cb';
-        } else {
-            $flag = '';
         }
     }
 
@@ -440,7 +436,6 @@ sub statements {
 	[ map {
 	    my ($date, $description, $amount) = @$_;
 	    my ($day, $month, $year) = $date =~ m|(\d+)/(\d+)/(\d+)|;
-            print STDERR $date, "\n";
 	    Finance::Bank::LaPoste::Statement->new(day => $day, month => $month, year => $year, description => $description, amount => $amount);
 	} @$l ];
     };
